/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { Session } from '@zowe/imperative';
import { IDeleteJobParms } from '../../doc/input/IDeleteJobParms';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
import { IJob } from '../../doc/response/IJob';
/**
 * Class to handle deletion of job information
 * @export
 * @class DeleteJobs
 */
export declare class DeleteJobs {
    /**
     * Cancel and purge a job
     * @static
     * @param {Session} session - connection info
     * @param {string} jobname - job name to be translated into parms object
     * @param {string} jobid - job id to be translated into parms object
     * @returns {Promise<IRestApiResponse>} - promise that resolves when the API call is complete
     * @memberof DeleteJobs
     */
    static deleteJob(session: Session, jobname: string, jobid: string): Promise<IRestApiResponse>;
    /**
     * Cancel and purge a job
     * Alternative version of the delete API accepting an IJob object returned from other APIs such as GetJobs and SubmitJobs
     * @static
     * @param {Session}         session         - connection info
     * @param {string}          jobname         - the job that you want to delete
     * @param {string}          jobid           - the job that you want to delete
     * @param {"1.0"| "2.0"}    modifyVersion   - version of the X-IBM-Job-Modify-Version header to use (see Headers)
     * @returns {Promise<IRestApiResponse>}     - promise that resolves when the API call is completel
     * @memberof DeleteJobs
     */
    static deleteJobForJob(session: Session, job: IJob): Promise<IRestApiResponse>;
    /**
     * Cancel and purge a job
     * Full version of the API with a parameter object
     * @static
     * @param {Session}             session - connection info
     * @param {IDeleteJobParms}     parms   - parm object (see IDeleteJobParms interface for details)
     * @returns {Promise<IRestApiResponse>} - promise that resolves when the API call is complete
     * @memberof DeleteJobs
     */
    static deleteJobCommon(session: Session, parms: IDeleteJobParms): Promise<IRestApiResponse>;
    /**
     * Getter for brightside logger
     * @returns {Logger}
     */
    private static get log();
}
