/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as zowe from '@zowe/cli';
import * as imperative from '@zowe/imperative';
import { ZoweExplorerApi } from '@zowe/zowe-explorer-api/lib/profiles';
import { IUploadRseOptions } from '../methods/upload/doc/IUploadRseOptions';
import { IDownloadRseOptions } from '../methods/download/doc';
export declare class RseRestApiCommon implements ZoweExplorerApi.ICommon {
    profile?: imperative.IProfileLoaded;
    static getProfileTypeName(): string;
    private session;
    constructor(profile?: imperative.IProfileLoaded);
    getProfileTypeName(): string;
    getSessionFromCommandArgument(cmdArgs: imperative.ICommandArguments): imperative.Session;
    getSession(profile?: imperative.IProfileLoaded): imperative.Session;
    getStatus(validateProfile?: imperative.IProfileLoaded, profileType?: string): Promise<string>;
    getTokenTypeName(): string;
    login(session: imperative.Session): Promise<string>;
    logout(session: imperative.Session): Promise<void>;
}
export declare class RseRestUssApi extends RseRestApiCommon implements ZoweExplorerApi.IUss {
    /**
     * Static function that is used to register the RSE API
     * with a ZoweExplorerApi.IApiRegisterClient instance.
     *
     * @static
     * @param {ZoweExplorerApi.IApiRegisterClient} apiRegister
     */
    static registerApi(apiRegister: ZoweExplorerApi.IApiRegisterClient): void;
    fileList(ussFilePath: string): Promise<zowe.IZosFilesResponse>;
    isFileTagBinOrAscii(ussFilePath: string): Promise<boolean>;
    getContents(inputFilePath: string, options: IDownloadRseOptions): Promise<zowe.IZosFilesResponse>;
    putContents(inputFilePath: string, ussFilePath: string, binary?: boolean, encoding?: string, etag?: string, returnEtag?: boolean): Promise<zowe.IZosFilesResponse>;
    putContent(inputFilePath: string, ussFilePath: string, options: IUploadRseOptions): Promise<zowe.IZosFilesResponse>;
    uploadDirectory(inputDirectoryPath: string, ussDirectoryPath: string, options?: IUploadRseOptions): Promise<zowe.IZosFilesResponse>;
    create(ussPath: string, type: string, mode?: string): Promise<zowe.IZosFilesResponse>;
    delete(ussPath: string, recursive?: boolean): Promise<zowe.IZosFilesResponse>;
    rename(currentUssPath: string, newUssPath: string): Promise<zowe.IZosFilesResponse>;
}
export declare class RseRestMvsApi extends RseRestApiCommon implements ZoweExplorerApi.IMvs {
    private static mappingsFilePath;
    /**
     * Static function that is used to register the RSE API
     * with a ZoweExplorerApi.IApiRegisterClient instance.
     *
     * @static
     * @param {ZoweExplorerApi.IApiRegisterClient} apiRegister
     */
    static registerApi(apiRegister: ZoweExplorerApi.IApiRegisterClient): void;
    /**
     * Static function to register a mapping file to be used for read/write operations.
     * Can be called many times when client setting change to be updated.
     *
     * @static
     * @param {string} mappingsFilePath an absolute path for a RSE API mappings file to be used for read/write operations
     */
    static registerMappingsFile(mappingsFilePath: string): void;
    /**
     * If Zowe Explorer is started with a mappings file via settings then clients
     * can retrieve the mappings file here.
     *
     * @returns {(string | undefined)} full path to the mappings file used for Zowe Explorer
     */
    static getMappingsFile(): string | undefined;
    /**
     * Static function that can be used to reset the cached mappingsFilePath.
     *
     * @static
     */
    static clearMappingsFile(): void;
    dataSet(filter: string, options?: zowe.IListOptions): Promise<zowe.IZosFilesResponse>;
    allMembers(dataSetName: string, options?: zowe.IListOptions): Promise<zowe.IZosFilesResponse>;
    getContents(dataSetName: string, options?: IDownloadRseOptions, mappingsFilePath?: string): Promise<zowe.IZosFilesResponse>;
    putContents(inputPath: string, dataSetName: string, options?: IUploadRseOptions, mappingsFilePath?: string): Promise<zowe.IZosFilesResponse>;
    private findMappingsFile;
    createDataSet(dataSetType: zowe.CreateDataSetTypeEnum, dataSetName: string, options?: Partial<zowe.ICreateDataSetOptions>): Promise<zowe.IZosFilesResponse>;
    createDataSetMember(dataSetName: string, options?: zowe.IUploadOptions): Promise<zowe.IZosFilesResponse>;
    deleteDataSet(dataSetName: string, options?: zowe.IDeleteDatasetOptions): Promise<zowe.IZosFilesResponse>;
    copyDataSetMember({ dataSetName: fromDataSetName, memberName: fromMemberName }: zowe.IDataSet, { dataSetName: toDataSetName, memberName: toMemberName }: zowe.IDataSet, _options?: zowe.ICopyDatasetOptions): Promise<zowe.IZosFilesResponse>;
    allocateLikeDataSet(dataSetName: string, likeDataSetName: string): Promise<zowe.IZosFilesResponse>;
    renameDataSet(currentDataSetName: string, newDataSetName: string): Promise<zowe.IZosFilesResponse>;
    renameDataSetMember(currentMemberName: string, newMemberName: string, afterMemberName: string): Promise<zowe.IZosFilesResponse>;
    hMigrateDataSet(dataSetName: string): Promise<zowe.IZosFilesResponse>;
    hRecallDataSet(dataSetName: string): Promise<zowe.IZosFilesResponse>;
}
export declare class RseRestJesApi extends RseRestApiCommon implements ZoweExplorerApi.IJes {
    /**
     * Static function that is used to register the RSE API
     * with a ZoweExplorerApi.IApiRegisterClient instance.
     *
     * @static
     * @param {ZoweExplorerApi.IApiRegisterClient} apiRegister
     */
    static registerApi(apiRegister: ZoweExplorerApi.IApiRegisterClient): void;
    getJobsByOwnerAndPrefix(owner: string, prefix: string): Promise<zowe.IJob[]>;
    getJob(jobid: string): Promise<zowe.IJob>;
    getSpoolFiles(jobname: string, jobid: string): Promise<zowe.IJobFile[]>;
    downloadSpoolContent(parms: zowe.IDownloadAllSpoolContentParms): Promise<void>;
    getSpoolContentById(jobname: string, jobid: string, spoolId: number): Promise<string>;
    getJclForJob(job: zowe.IJob): Promise<string>;
    submitJcl(jcl: string, internalReaderRecfm?: string, internalReaderLrecl?: string): Promise<zowe.IJob>;
    submitJob(jobDataSet: string): Promise<zowe.IJob>;
    deleteJob(jobname: string, jobid: string): Promise<void>;
}
/**
 * An implementation of the Zowe Explorer Command API interface for RSE.
 */
export declare class RseRestCommandApi extends RseRestApiCommon implements ZoweExplorerApi.ICommand {
    /**
     * Static function that is used to register the RSE API
     * with a ZoweExplorerApi.IApiRegisterClient instance.
     *
     * @static
     * @param {ZoweExplorerApi.IApiRegisterClient} apiRegister
     */
    static registerApi(apiRegister: ZoweExplorerApi.IApiRegisterClient): void;
    issueTsoCommand(command: string, acctNum?: string): Promise<zowe.IIssueResponse>;
    issueMvsCommand(command: string): Promise<zowe.IConsoleResponse>;
}
